;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "password-store-menu" "20250706.1858"
  "A better, more complete UI for password-store."
  '((emacs          "29.1")
    (password-store "2.3.2")
    (transient      "0.8.3"))
  :url "https://github.com/rjekker/password-store-menu"
  :commit "31b0884d1cdc80ad4ee7d84680c11653e659bb18"
  :revdesc "31b0884d1cdc"
  :keywords '("convenience" "data" "files")
  :authors '(("Reindert-Jan Ekker" . "info@rjekker.nl"))
  :maintainers '(("Reindert-Jan Ekker" . "info@rjekker.nl")))
